==> client-java-api-3.0.0-sources.jar: io/kubernetes/client/models/V1DownwardAPIVolumeSourceFluent.java <==
package io.kubernetes.client.models;

import com.google.gson.annotations.SerializedName;
import io.kubernetes.client.fluent.Fluent;
import io.kubernetes.client.fluent.Nested;
import java.util.ArrayList;
import java.lang.String;
import io.kubernetes.client.fluent.Predicate;
import java.lang.Integer;
import java.lang.Deprecated;
import java.util.Collection;
import java.util.List;
import java.lang.Boolean;

public interface V1DownwardAPIVolumeSourceFluent<A extends V1DownwardAPIVolumeSourceFluent<A>> extends Fluent<A>{


    public Integer getDefaultMode();
    public A withDefaultMode(Integer defaultMode);
    public Boolean hasDefaultMode();
    public A withNewDefaultMode(int arg1);
    public A withNewDefaultMode(String arg1);
    public A addToItems(int index,V1DownwardAPIVolumeFile item);
    public A setToItems(int index,V1DownwardAPIVolumeFile item);
    public A addToItems(V1DownwardAPIVolumeFile... items);
    public A addAllToItems(Collection<V1DownwardAPIVolumeFile> items);
    public A removeFromItems(V1DownwardAPIVolumeFile... items);
    public A removeAllFromItems(Collection<V1DownwardAPIVolumeFile> items);
    
/**
 * This method has been deprecated, please use method buildItems instead.
 * @return The buildable object.
 */
@Deprecated public List<V1DownwardAPIVolumeFile> getItems();
    public List<V1DownwardAPIVolumeFile> buildItems();
    public V1DownwardAPIVolumeFile buildItem(int index);
    public V1DownwardAPIVolumeFile buildFirstItem();
    public V1DownwardAPIVolumeFile buildLastItem();
    public V1DownwardAPIVolumeFile buildMatchingItem(io.kubernetes.client.fluent.Predicate<V1DownwardAPIVolumeFileBuilder> predicate);
    public A withItems(List<V1DownwardAPIVolumeFile> items);
    public A withItems(V1DownwardAPIVolumeFile... items);
    public Boolean hasItems();
    public V1DownwardAPIVolumeSourceFluent.ItemsNested<A> addNewItem();
    public V1DownwardAPIVolumeSourceFluent.ItemsNested<A> addNewItemLike(V1DownwardAPIVolumeFile item);
    public V1DownwardAPIVolumeSourceFluent.ItemsNested<A> setNewItemLike(int index,V1DownwardAPIVolumeFile item);
    public V1DownwardAPIVolumeSourceFluent.ItemsNested<A> editItem(int index);
    public V1DownwardAPIVolumeSourceFluent.ItemsNested<A> editFirstItem();
    public V1DownwardAPIVolumeSourceFluent.ItemsNested<A> editLastItem();
    public V1DownwardAPIVolumeSourceFluent.ItemsNested<A> editMatchingItem(io.kubernetes.client.fluent.Predicate<V1DownwardAPIVolumeFileBuilder> predicate);

    public interface ItemsNested<N> extends io.kubernetes.client.fluent.Nested<N>,V1DownwardAPIVolumeFileFluent<V1DownwardAPIVolumeSourceFluent.ItemsNested<N>>{

        
    public N and();    public N endItem();
}


}

==> client-java-api-5.0.0-sources.jar: io/kubernetes/client/models/V1DownwardAPIVolumeSourceFluent.java <==
package io.kubernetes.client.models;

import com.google.gson.annotations.SerializedName;
import io.kubernetes.client.fluent.Fluent;
import io.kubernetes.client.fluent.Nested;
import java.util.ArrayList;
import io.kubernetes.client.fluent.Predicate;
import java.lang.Integer;
import java.lang.Deprecated;
import java.util.Collection;
import java.util.List;
import java.lang.Boolean;

public interface V1DownwardAPIVolumeSourceFluent<A extends V1DownwardAPIVolumeSourceFluent<A>> extends Fluent<A>{


    public Integer getDefaultMode();
    public A withDefaultMode(Integer defaultMode);
    public Boolean hasDefaultMode();
    public A addToItems(int index,V1DownwardAPIVolumeFile item);
    public A setToItems(int index,V1DownwardAPIVolumeFile item);
    public A addToItems(V1DownwardAPIVolumeFile... items);
    public A addAllToItems(Collection<V1DownwardAPIVolumeFile> items);
    public A removeFromItems(V1DownwardAPIVolumeFile... items);
    public A removeAllFromItems(Collection<V1DownwardAPIVolumeFile> items);
    
/**
 * This method has been deprecated, please use method buildItems instead.
 * @return The buildable object.
 */
@Deprecated public List<V1DownwardAPIVolumeFile> getItems();
    public List<V1DownwardAPIVolumeFile> buildItems();
    public V1DownwardAPIVolumeFile buildItem(int index);
    public V1DownwardAPIVolumeFile buildFirstItem();
    public V1DownwardAPIVolumeFile buildLastItem();
    public V1DownwardAPIVolumeFile buildMatchingItem(io.kubernetes.client.fluent.Predicate<V1DownwardAPIVolumeFileBuilder> predicate);
    public Boolean hasMatchingItem(io.kubernetes.client.fluent.Predicate<V1DownwardAPIVolumeFileBuilder> predicate);
    public A withItems(List<V1DownwardAPIVolumeFile> items);
    public A withItems(V1DownwardAPIVolumeFile... items);
    public Boolean hasItems();
    public V1DownwardAPIVolumeSourceFluent.ItemsNested<A> addNewItem();
    public V1DownwardAPIVolumeSourceFluent.ItemsNested<A> addNewItemLike(V1DownwardAPIVolumeFile item);
    public V1DownwardAPIVolumeSourceFluent.ItemsNested<A> setNewItemLike(int index,V1DownwardAPIVolumeFile item);
    public V1DownwardAPIVolumeSourceFluent.ItemsNested<A> editItem(int index);
    public V1DownwardAPIVolumeSourceFluent.ItemsNested<A> editFirstItem();
    public V1DownwardAPIVolumeSourceFluent.ItemsNested<A> editLastItem();
    public V1DownwardAPIVolumeSourceFluent.ItemsNested<A> editMatchingItem(io.kubernetes.client.fluent.Predicate<V1DownwardAPIVolumeFileBuilder> predicate);

    public interface ItemsNested<N> extends io.kubernetes.client.fluent.Nested<N>,V1DownwardAPIVolumeFileFluent<V1DownwardAPIVolumeSourceFluent.ItemsNested<N>>{

        
    public N and();    public N endItem();
}


}
